﻿Imports Windows.Data.Json

Namespace ParseJSON.Utility
    Friend Module JsonObjectExtensions
        <System.Runtime.CompilerServices.Extension> _
        Public Function GetBooleanValue(ByVal jsonObject As JsonObject, ByVal key As String) As Boolean?
            Dim value As IJsonValue
            Dim returnValue? As Boolean = Nothing

            If jsonObject.ContainsKey(key) Then
                If jsonObject.TryGetValue(key, value ) Then
                    If value.ValueType = JsonValueType.String Then
                        Dim v As String = jsonObject.GetNamedString(key).ToLower()
                        If v = "1" OrElse v = "true" Then
                            returnValue = True
                        ElseIf v = "0" OrElse v = "false" Then
                            returnValue = False
                        End If
                    ElseIf value.ValueType = JsonValueType.Number Then
                        Dim v As Integer = Convert.ToInt32(jsonObject.GetNamedNumber(key))
                        If v = 1 Then
                            returnValue = True
                        ElseIf v = 0 Then
                            returnValue = False
                        End If
                    ElseIf value.ValueType = JsonValueType.Boolean Then
                        returnValue = value.GetBoolean()
                    End If
                End If
            End If

            Return returnValue
        End Function

        <System.Runtime.CompilerServices.Extension> _
        Public Function GetDoubleValue(ByVal jsonObject As JsonObject, ByVal key As String) As Double?
            Dim value As IJsonValue
            Dim returnValue? As Double = Nothing
            Dim parsedValue As Double

            If jsonObject.ContainsKey(key) Then
                If jsonObject.TryGetValue(key, value) Then
                    If value.ValueType = JsonValueType.String Then
                        If Double.TryParse(jsonObject.GetNamedString(key), parsedValue) Then
                            returnValue = parsedValue
                        End If
                    ElseIf value.ValueType = JsonValueType.Number Then
                        returnValue = jsonObject.GetNamedNumber(key)
                    End If
                End If
            End If

            Return returnValue
        End Function

        <System.Runtime.CompilerServices.Extension> _
        Public Function GetIntegerValue(ByVal jsonObject As JsonObject, ByVal key As String) As Integer?
            Dim value? As Double = jsonObject.GetDoubleValue(key)
            Dim returnValue? As Integer = Nothing

            If value.HasValue Then
                returnValue = Convert.ToInt32(value.Value)
            End If

            Return returnValue
        End Function

        <System.Runtime.CompilerServices.Extension> _
        Public Function GetStringValue(ByVal jsonObject As JsonObject, ByVal key As String) As String
            Dim value As IJsonValue
            Dim returnValue As String = String.Empty

            If jsonObject.ContainsKey(key) Then
                If jsonObject.TryGetValue(key, value) Then
                    If value.ValueType = JsonValueType.String Then
                        returnValue = jsonObject.GetNamedString(key)
                    ElseIf value.ValueType = JsonValueType.Number Then
                        returnValue = jsonObject.GetNamedNumber(key).ToString()
                    ElseIf value.ValueType = JsonValueType.Boolean Then
                        returnValue = jsonObject.GetNamedBoolean(key).ToString()
                    End If
                End If
            End If

            Return returnValue
        End Function
    End Module
End Namespace

